@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.15 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.15 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XmlReader
@@ -96,7 +96,7 @@ class SyL_Config extends SyL_XmlReader
      * @param string ٥̾
      * @return object ե륪֥
      */
-    function &getObject($config_name, $file_names, &$controller)
+    function &factory($config_name, $file_names, &$controller)
     {
         $class_name = 'SyL_Config' . ucfirst($config_name);
         include_once SYL_INCLUDE_DIR . "/framework/Config/{$class_name}.php";
@@ -119,11 +119,11 @@ class SyL_Config extends SyL_XmlReader
      * å奪֥Ȥ
      *
      * @access public
-     * @param string åǥ쥯ȥ
+     * @param string åƬ
      * @param string ɲåʸ
      * @return object å奪֥
      */
-    function &getCacheObject($cache_dir, $ext_key='')
+    function &getCache($key)
     {
         // åѤ
         $mtime = 0;
@@ -134,14 +134,20 @@ class SyL_Config extends SyL_XmlReader
             }
         }
 
-        $cache =& SyL_Cache::getObject('fileinclude');
-        $cache->setKey(implode('', $this->file_names) . $ext_key);
-        $cache->setCacheDir($cache_dir);
-        $this->config = $cache->read(false, $mtime);
-        if (!$this->config) {
+        $cache =& SyL_Cache::factory(SYL_CACHE);
+        $cache->setPrefix(basename($this->file_names[0]) . '.');
+        $cache->setKey($key);
+        $cache->setMinModifyTime($mtime);
+
+        //$cache->useIncludeCache();
+
+        $this->config = $cache->read();
+        if ($this->config) {
+            // åOK
+            $cache = null;
             return $cache;
         } else {
-            $cache = null;
+            // åNG
             return $cache;
         }
     }
@@ -188,17 +194,6 @@ class SyL_Config extends SyL_XmlReader
     {
         return $this->config;
     }
-
-    /**
-     * ꥭå
-     * 
-     * @access public
-     * @return string ꥭå
-     */
-    function getCache()
-    {
-        return 'return ' . var_export($this->config, true) . ';';
-    }
 }
 
 ?>
