@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.24 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.25 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.24 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.25 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -203,7 +203,11 @@ class SyL_Controller
         }
 
         // ɤ߹
-        call_user_func(array(&$this, 'readDefines'));
+        if (isset($config['define']) && $config['define']) {
+            $this->readDefines($config['define']);
+        } else {
+            $this->readDefines();
+        }
 
         // ǥ쥯ȥ
         $this->action_dir = SYL_APP_DIR . '/actions';
@@ -255,8 +259,9 @@ class SyL_Controller
      * ɤ߹
      *
      * @access public
+     * @param string ɲե
      */
-    function readDefines()
+    function readDefines($define='')
     {
         $config_files = array();
         // ץꥱͤɤ߹
@@ -266,8 +271,10 @@ class SyL_Controller
         }
         // Хͤɤ߹
         $config_files[] = SYL_PROJECT_CONFIG_DIR . "/{$this->defines_file_name}";
-
-        // åѤʤ
+        // ɲե
+        if ($define) {
+            $config_files[] = $define;
+        }
         $config =& SyL_Config::factory('defines', $config_files, $this);
         $config->parseXml();
     }
