@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.3 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.3 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDaoTable
@@ -79,6 +79,13 @@ class SyL_DBDaoTable
      * @var array
      */
     var $data_columns = array();
+    /**
+     * оݥSQLؿ
+     * 
+     * @access private
+     * @var array
+     */
+    var $data_functions = array();
     /**
      * 索֥
      * 
@@ -93,6 +100,13 @@ class SyL_DBDaoTable
      * @var array
      */
     var $order_bys = array();
+    /**
+     * 롼ײ
+     * 
+     * @access protected
+     * @var array
+     */
+    var $group_bys = array();
 
     /**
      * 󥹥ȥ饯
@@ -112,13 +126,17 @@ class SyL_DBDaoTable
      * @access public
      * @param string ̾
      * @param mixed 
+     * @param array SQLؿ̾
      */
-    function addColumn($name, $value=null)
+    function addColumn($name, $value=null, $function=array())
     {
         // ʸ
         $name = strtoupper($name);
         if (isset($this->columns[$name])) {
             $this->data_columns[$name] = $value;
+            if (is_array($function) && (count($function) > 0)) {
+                $this->data_functions[$name] = $function;
+            }
         } else {
             trigger_error("[SyL error] Column name not found in " . get_class($this) . " class ({$name})", E_USER_ERROR);
         }
@@ -189,12 +207,12 @@ class SyL_DBDaoTable
      * @access public
      * @return array 祭
      */
-    function getPrimary()
+    function getPrimary($alias_flag=true)
     {
         $alias = $this->getAliasName();
         $primary = array();
         foreach ($this->primary as $tmp) {
-            $primary[] = "{$alias}.{$tmp}";
+            $primary[] = ($alias_flag) ? "{$alias}.{$tmp}" : $tmp;
         }
         return $primary;
     }
@@ -216,12 +234,13 @@ class SyL_DBDaoTable
      * @access public
      * @return object 索֥
      */
-    function getConditions()
+    function getConditions($alias_flag=true)
     {
-        if ($this->conditions !== null) {
-            $this->conditions->setAlias($this->getAliasName());
+        $conditions = $this->conditions;
+        if ($alias_flag && ($conditions !== null)) {
+            $conditions->setAlias($this->getAliasName());
         }
-        return $this->conditions;
+        return $conditions;
     }
 
     /**
@@ -236,7 +255,9 @@ class SyL_DBDaoTable
         // ʸ
         $name = strtoupper(trim($name));
         if (isset($this->columns[$name])) {
-            $this->order_bys[] = array($name, $asc);
+            $this->order_bys[] = array($name, $asc, false);
+        } else if (array_search($name, $this->data_columns) !== false) {
+            $this->order_bys[] = array($name, $asc, true);
         } else {
             trigger_error("[SyL error] Sort column name not found in " . get_class($this) . " class ({$name})", E_USER_ERROR);
         }
@@ -265,7 +286,7 @@ class SyL_DBDaoTable
      * @param bool 祭ȥե饰
      * @return array ȥ
      */
-    function getSorts($primary_sort=true)
+    function getSorts($primary_sort=false)
     {
         $order_bys = $this->order_bys;
         if ($primary_sort) {
@@ -278,7 +299,7 @@ class SyL_DBDaoTable
                     }
                 }
                 if (!$exist) {
-                    $order_bys[] = array($primary, true);
+                    $order_bys[] = array($primary, true, false);
                 }
             }
         }
@@ -286,7 +307,49 @@ class SyL_DBDaoTable
         $result = array();
         for ($i=0; $i<count($order_bys); $i++) {
             $sort = ($order_bys[$i][1]) ? 'ASC' : 'DESC';
-            $result[$i] = $this->getAliasName() . '.' . $order_bys[$i][0] . ' ' . $sort;
+            if ($order_bys[$i][2]) {
+                $result[$i] = $order_bys[$i][0] . ' ' . $sort;
+            } else {
+                $result[$i] = $this->getAliasName() . '.' . $order_bys[$i][0] . ' ' . $sort;
+            }
+        }
+        return $result;
+    }
+
+    /**
+     * 롼ײɲ
+     *
+     * @access public
+     * @param string 롼ײ
+     */
+    function addGroup($name)
+    {
+        // ʸ
+        $name = strtoupper(trim($name));
+        if (isset($this->columns[$name])) {
+            $this->group_bys[] = array($name, false);
+        } else if (array_search($name, $this->data_columns) !== false) {
+            $this->group_bys[] = array($name, true);
+        } else {
+            trigger_error("[SyL error] Group column name not found in " . get_class($this) . " class ({$name})", E_USER_ERROR);
+        }
+    }
+
+    /**
+     * 롼ײ
+     *
+     * @access public
+     * @return array 롼ײ
+     */
+    function getGroups()
+    {
+        $result = array();
+        for ($i=0; $i<count($this->group_bys); $i++) {
+            if ($this->group_bys[$i][1]) {
+                $result[$i] = $this->group_bys[$i][0];
+            } else {
+                $result[$i] = $this->getAliasName() . '.' . $this->group_bys[$i][0];
+            }
         }
         return $result;
     }
@@ -297,22 +360,32 @@ class SyL_DBDaoTable
      * @access public
      * @return array SELECT
      */
-    function getSelectColumns()
+    function getSelectColumns(&$conn)
     {
-        $columns = array();
+        $columns_tmp = array();
         if (count($this->data_columns) > 0) {
-            foreach ($this->data_columns as $name => $value) {
-                if ($value) {
-                    $name .= " AS {$value}";
-                }
-                $columns[] = $name;
-            }
+            $columns_tmp = $this->data_columns;
         } else {
-            $columns = array_keys($this->columns);
+            foreach ($this->columns as $name => $value) {
+                $columns_tmp[$name] = null;
+            }
         }
 
-        for ($i=0; $i<count($columns); $i++) {
-            $columns[$i] = $this->getAliasName() . '.' . $columns[$i];
+        $columns = array();
+        foreach ($columns_tmp as $name => $column_alias) {
+            $column_tmp = '';
+            if (isset($this->data_functions[$name])) {
+                $funcs    = $this->data_functions[$name];
+                $funcname = array_shift($funcs);
+                $func = implode(',', array_map(array(&$conn, 'quote'), $funcs));
+                if ($func != '') {
+                    $func = ',' . $func;
+                }
+                $column_tmp = $funcname . '(' . $this->getAliasName() . '.' . $name . $func . ')';
+            } else {
+                $column_tmp = $this->getAliasName() . '.' . $name;
+            }
+            $columns[] = ($column_alias) ? "{$column_tmp} AS {$column_alias}" : $column_tmp;
         }
         return $columns;
     }
@@ -326,31 +399,35 @@ class SyL_DBDaoTable
     function getSelectHeaders()
     {
         $alias = $this->getAliasName() . '.';
-        $columns     = array();
-        $tmp_columns = array();
+        $tmp_columns    = array();
+        $column_aliases = array();
         if (count($this->data_columns) > 0) {
             foreach (array_keys($this->data_columns) as $name) {
+                if ($this->data_columns[$name]) {
+                    $column_aliases[$name] = $this->data_columns[$name];
+                }
                 $tmp_columns[$name] = $this->columns[$name];
             }
         } else {
             $tmp_columns =& $this->columns;
         }
-        foreach ($tmp_columns as $name => $name1) {
-            $columns[$alias.$name]['name']     = ($name1) ? $name1 : $name;
-            $columns[$alias.$name]['primary']  = in_array($name, $this->primary);
+
+        $columns = array();
+        foreach (array_keys($tmp_columns) as $name) {
+            $column_name = isset($column_aliases[$name]) ? $column_aliases[$name] : $alias . $name;
             $exist = false;
             foreach ($this->getSorts() as $order_by) {
                 list($sort, $order) = explode(' ', $order_by, 2);
-                if (($alias.$name) == $sort) {
-                    $columns[$alias.$name]['order'] = ($order == 'ASC') ? 'DESC' : 'ASC'; // 󥯤ʤΤǥȤ
+                if (($column_name) == $sort) {
+                    $columns[$column_name]['order'] = ($order == 'ASC') ? 'DESC' : 'ASC'; // 󥯤ʤΤǥȤ
                     $exist = true;
                     break;
                 }
             }
             if (!$exist) {
-                $columns[$alias.$name]['order'] = 'ASC';
+                $columns[$column_name]['order'] = 'ASC';
             }
-            $columns[$alias.$name]['sortlink'] = $alias . $name . '.' . $columns[$alias.$name]['order'];
+            $columns[$column_name]['sortlink'] = $alias . $name . '.' . $columns[$column_name]['order'];
         }
         return $columns;
     }
@@ -374,6 +451,16 @@ class SyL_DBDaoTable
             return $this->data_columns;
         }
     }
+
+    /**
+     * ǡ
+     *
+     * @access public
+     */
+    function initDataColumns()
+    {
+        $this->data_columns = array();
+    }
 }
 
 ?>
