@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.3 2007/07/29 08:54:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,6 +44,10 @@
  * SQL饹
  */
 require_once 'SyL_DBSqlTableConditions.php';
+/**
+ * SQLϢ饹
+ */
+require_once 'SyL_DBSqlTableRelations.php';
 
 /**
  * DBѥǡ饹
@@ -52,7 +56,7 @@ require_once 'SyL_DBSqlTableConditions.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.3 2007/07/29 08:54:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -134,7 +138,7 @@ class SyL_DBDao
     }
 
     /**
-     * 索֥Ⱥ
+     * ơ֥索֥Ⱥ
      *
      * @access public
      * @return object 索֥
@@ -144,6 +148,17 @@ class SyL_DBDao
         return new SyL_DBSqlTableConditions();
     }
 
+    /**
+     * ơ֥Ϣ֥Ⱥ
+     *
+     * @access public
+     * @return object Ϣ֥
+     */
+    function createRelation()
+    {
+        return new SyL_DBSqlTableRelations();
+    }
+
     /**
      * SELECTܤ
      *
@@ -190,32 +205,15 @@ class SyL_DBDao
         return $this->pager;
     }
 
-    /**
-     * ץ饤ޥꥭ
-     *
-     * @access public
-     * @return object ڡ֥
-     */
-    function getPrimary($table)
-    {
-        // ѤѴ
-        $table = $this->arrangeTables($table);
-
-        $primary = array();
-        foreach(array_keys($table) as $name) {
-            $primary = array_merge($primary, $table[$name]->getPrimary());
-        }
-        return $primary;
-    }
-
     /**
      * DBǡ
      *
      * @access public
      * @param object or array ơ֥륪֥ 
+     * @param object Ϣ֥
      * @return array ǡ
      */
-    function select($table)
+    function select($table, $relation=null)
     {
         // ѤѴ
         $table = $this->arrangeTables($table);
@@ -223,19 +221,34 @@ class SyL_DBDao
         $selects   = array();
         $froms     = array();
         $wheres    = array();
+        $group_bys = array();
         $order_bys = array();
         $this->select_headers = array();
         foreach(array_keys($table) as $name) {
-            $selects    = array_merge($selects, $table[$name]->getSelectColumns());
+            $selects    = array_merge($selects, $table[$name]->getSelectColumns($this->conn));
             $froms      = array_merge($froms, (array)$table[$name]->getSelectName());
             $conditions = $table[$name]->getConditions();
-            $wheres[]   = ($conditions) ? $conditions->getWhere($this->conn) : '';
+            if ($conditions) {
+                $where = $conditions->getWhere($this->conn);
+                if ($where) {
+                    $wheres[] = $where;
+                }
+            }
+            $group_bys  = array_merge($group_bys, $table[$name]->getGroups());
             $order_bys  = array_merge($order_bys, $table[$name]->getSorts());
             // SELECTݻ
             $this->select_headers = array_merge($this->select_headers, $table[$name]->getSelectHeaders());
         }
 
+        // Ϣ糧å
+        if (is_object($relation)) {
+            $where = $relation->getWhere();
+            if ($where) {
+                array_unshift($wheres, $where);
+            }
+        }
         $where    = implode(' AND ', $wheres);
+        $group_by = implode(', ', $group_bys);
         $order_by = implode(', ', $order_bys);
         // ȥȥݻ
         $this->sort_columns = str_replace(' ', '.', $order_bys);
@@ -249,11 +262,18 @@ class SyL_DBDao
         $sql .= "WHERE ";
         $sql .=   $where . " ";
         }
+        if ($group_by) {
+        $sql .= "GROUP BY ";
+        $sql .=   $group_by . " ";
+        }
         if ($order_by) {
         $sql .= "ORDER BY ";
         $sql .=   $order_by . " ";
         }
 
+//echo $sql;
+//exit;
+
         if ($this->page === 0) {
             // ̾
             return $this->conn->query($sql);
@@ -343,7 +363,7 @@ class SyL_DBDao
     {
         $result = true;
         foreach (array_keys($table) as $name) {
-            $conditions = $table[$name]->getConditions();
+            $conditions = $table[$name]->getConditions(false);
             $where      = ($conditions) ? $conditions->getWhere($this->conn) : '';
             if (!$this->conn->execPerform($table[$name]->getName(), $table[$name]->getDataColumns(), $action, $where)) {
                 $result = false;
