@@ -27,11 +27,16 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.18 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * DB޼饹
+ */
+require_once 'DB/SyL_DBSchema.php';
+
 /**
  *  DB饹
  *
@@ -39,7 +44,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.18 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -120,6 +125,13 @@ class SyL_DB
      * @var string
      */
     var $last_error_message = '';
+    /**
+     * ǽSQL
+     * 
+     * @access protected
+     * @var string
+     */
+    var $last_sql = '';
     /**
      * SQLХå᥽å
      * 
@@ -279,7 +291,7 @@ class SyL_DB
      */
     function escapeLike($parameter)
     {
-        return preg_replace('/(\_|\%)/', '\\\\$1', $parameter);
+        return preg_replace('/(\_|\%)/', '\\\\$1', $this->escape($parameter));
     }
 
     /**
@@ -359,14 +371,16 @@ class SyL_DB
     {
         // SQL
         call_user_func($this->callback_sql_log, $sql);
-
+        // SQLݻ
+        $this->last_sql = $sql;
         // ᥽å̾
         list($method) = explode(' ', $sql, 2);
 
         // SQL¹
         $result = false;
         switch (strtolower($method)) {
-        case 'select': $result = $this->execSelect($sql); break;
+        case 'select': 
+        case 'show':  $result = $this->execSelect($sql); break;
         case 'insert':
         case 'update':
         case 'delete': $result = $this->execUpdate($sql); break;
@@ -764,7 +778,7 @@ class SyL_DB
     function getErrorMessage()
     {
         if ($this->errorInfo()) {
-            return $error_message = "[SyL DB Error " . $this->errorCode() . "] " . $this->errorInfo();
+            return $error_message = "[SyL DB Error " . $this->errorCode() . "] " . $this->errorInfo() . "<br>\n----------<br>\n{$this->last_sql}<br>\n----------<br>\n";
         } else {
             return '';
         }
@@ -899,6 +913,31 @@ class SyL_DB
     function logError($error_message)
     {
     }
+
+    /**
+     * ³ƤDBΥơ֥
+     *
+     * @access public
+     * @return array ơ֥
+     */
+    function getTables()
+    {
+        $schema =& SyL_DBSchema::factory($this);
+        return $schema->getTables();
+    }
+
+    /**
+     * ꤷơ֥Υ
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array 
+     */
+    function getColumns($tablename)
+    {
+        $schema =& SyL_DBSchema::factory($this);
+        return $schema->getColumns($tablename);
+    }
 }
 
 ?>
